# Find the active init system
[ $(pidof systemd) ] && INIT_SYSTEM=systemd
[ $(pidof /sbin/init) ] && INIT_SYSTEM=systemv

echo "# $EXTENSION/build_order.txt" 				 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 				>> $EXTENSION/build_order.txt
echo "" 											>> $EXTENSION/build_order.txt

if [[ $(command -v systemctl) != "" ]] && [ ! -d /etc/extension/startupfiles ]; then
	echo "blfssystemd" 								>> $EXTENSION/build_order.txt
fi
if [ -d /etc/rc.d ] && [ ! -d /etc/extension/startupfiles ]; then
	echo "blfsbootscripts" 							>> $EXTENSION/build_order.txt
fi
echo "complete _" 									>> $EXTENSION/build_order.txt
